%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Euclidean Distance
%[detection_function times] = Euclidean_Distance(STFT_in, times_in)
%  Outputs:
%  detection_function returns the values of the detection function applied
%  at times.
%  times are the times correspoinding to the detection_function features
%       times is a modified form of times_in, multiple initial points are
%       lost due to the initial conditions needed for the detection
%       algorithm.
% Inputs:
% STFT_in is the complexted domain STFT of the music signal
%       Rows represent the kth frequency bin
%       Columns represent the order in time the STFT was taken
% times_in are the corresponding times of the center of the STFT window
%      
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [detection_function times] = Euclidean_Distance(STFT_in, times_in) 
[nr nc] = size(STFT_in);
parfor k = 3:nc
    X_n = STFT_in(:,k)
    X_n_1 = STFT_in(:,k-1)
    X_n_2 = STFT_in(:,k-2)
    delta_phi = angle(X_n)-2*angle(X_n_1)+angle(X_n_2);
    euclid_dist = sqrt(abs(STFT_in(:,k)).^2 + abs(STFT_in(:,k-1)).^2  - 2*(abs(STFT_in(:,k)).*abs(STFT_in(:,k-1)).*cos(delta_phi)))
    [nr nc] = size(euclid_dist);
    detection_function(k-2) = sum(euclid_dist)/nr;
end
times = times_in(3:end);
end

